# Contributing

This document outlines in what areas and in what ways you can contribute to the Spartathlon app.


## Feedback and ideas

Since we don't run statistics tools we rely on your feedback to tell us how to make this app better.
Better for you and better for all the other Spartathletes, supporters and volunteers.

1) How did the app help you?
2) What functionality did you miss?
3) What problems did you have when using the app?

Reach us at [contact@spartathlon.app](mailto:contact@spartathlon.app) or open an issue on Gitlab.


## Translations

### Improving existing translations

Open an issue or email us stating the following information:

* Where the wrong text appears in the app
* The language
* The wrong text
* The correct text

For such small changes that's the easiest way (or send an MR if you absolutely want to).

### Adding a new language

Flutter uses the [ARB format](https://github.com/google/app-resource-bundle/wiki/ApplicationResourceBundleSpecification)
to store translations. Unfortunately we haven't yet seen a nice translation tool that handles this.

If you're not a developer, open an issue or email us and we'll get you started.

If you're a developer:

1) Fork the project and make sure it runs locally
2) Add the new locale to `lib/main.dart` and `lib/SpartaLocalizations.dart` and `ios/Runner/Info.plist`
3) Copy `lib/l10n/intl_messages_en.arb` to `lib/lib/l10n/intl_messages_LANGCODE.arb`
4) Edit `"@@locale": "LANGCODE"` and all the translations (e.g. `"sectionDashboard": "Übersicht",`)
5) Run `flutter pub run intl_translation:generate_from_arb --output-dir=lib/l10n --no-use-deferred-loading lib/SpartaLocalizations.dart lib/l10n/*.arb`
6) Build the app and verify the translations are applied correctly (note that the app follows your system language)
7) Open a merge request


## Code

This app is built with [Flutter](https://flutter.dev/). Getting familiar with Dart and Flutter will
be a good starting point if you want to contribute code.

First install Flutter: https://flutter.dev/docs/get-started/install

Then clone the code: `git clone git@gitlab.com:thgoebel/spartathlon.git`

Open the project in AndroidStudio. To run it, edit your run configuration to use the build flavor "play".
Alternatively from the command line call `flutter run --flavor=play`.

You might need additional setup steps (like installing the Flutter plugin for AndroidStudio or ADB
to run it on a physical device) that have been omitted here because they are not project-specific.

All development work is done on the `dev` branch. Fork a new branch from there and direct your
MR there, too.

If you want to implement larger features, we ask you to open an issue first so we can discuss
the design before you start putting a lot of work into it.

If you have any dev related questions feel free to email us at contact@spartathlon.app.
