/// Event model
class Event extends Comparable<Event> {
  DateTime from;
  DateTime to;
  String coordinates;
  String location;
  String description;

  Event({
    this.from,
    this.to,
    this.coordinates,
    this.location,
    this.description,
  });

  factory Event.fromJson(Map<String, dynamic> json) {
    // The 'Z' is appended to tell the parser that the time is in UTC
    // We get this guarantee from the API
    return Event(
      from: DateTime.parse(json["date"] + ' ' + json["timeFrom"] + 'Z'),
      to: (json["timeTo"] != null)
          ? DateTime.parse(json["date"] + ' ' + json["timeTo"] + 'Z')
          : null,
      coordinates: json["coordinates"].toString(),
      location: json["location"].toString(),
      description: json["description"].toString(),
    );
  }

  @override
  int compareTo(Event other) {
    return from.compareTo(other.from);
  }

  @override
  String toString() {
    return "Event from " +
        from.toString() +
        " until " +
        to.toString() +
        " called " +
        description;
  }

  bool isOnSameDayOrLater(DateTime other) {
    DateTime eventDate =
        DateTime.utc(this.from.year, this.from.month, this.from.day);
    DateTime nowDate = DateTime.utc(other.year, other.month, other.day);

    return eventDate.compareTo(nowDate) >= 0;
  }
}
