import 'dart:async';

import 'package:flutter_cache_manager/flutter_cache_manager.dart';
import 'package:path/path.dart' as p;
import 'package:path_provider/path_provider.dart';

import 'package:spartathlon_app/util/RaceTiming.dart';

const String BASE_URL_API_ISA =
    'https://www.spartathlon.gr/en/?option=com_ajax&plugin=spartathlon&format=json&action=';
const String BASE_URL_API_APP = 'https://spartathlon.app/api/';

/// Cache manager for all athlete data related network requests
class SpartaCacheManager extends BaseCacheManager {
  static const key = 'spartaCache';

  static SpartaCacheManager _instance;

  factory SpartaCacheManager() {
    if (_instance == null) {
      _instance = SpartaCacheManager._();
    }
    return _instance;
  }

  SpartaCacheManager._() // Private, named constructor
      : super(
          key,
          maxAgeCacheObject: _getAthleteCacheMaxAge(),
        );

  Future<String> getFilePath() async {
    var directory = await getTemporaryDirectory();
    return p.join(directory.path, key);
  }

  /// Shorten maximum cache age during the race when we want more regular updates
  /// Not regarding when the object was created but when it was last touched
  static Duration _getAthleteCacheMaxAge() {
    if (isRaceWeek()) {
      return Duration(hours: 1);
    } else {
      return Duration(days: 7);
    }
  }
}
