import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';
import 'package:platform/platform.dart';
import 'package:url_launcher/url_launcher.dart';

/// Corner radius for cards, dialogs, etc
const double cardCornerRadius = 8.0;

/// Elevations of material cards
const double cardElevation = 2.0;

/// Corner radius for Material buttons
const double buttonCornerRadius = 4.0;

/// The height of a LicenseTile in the licenses dialog
const double kLicenseTileHeight = 72.0;

/// The height of the yellow notice bar warning about no network connection
const double kNoNetworkBarHeight = 40.0;

/// The default blur radius for shadows
const double kShadowBlurRadius = 4.0;

/// Return a string with a URL to open that location in a maps app.
///
/// The URI starts with geo:// on Android or with maps:// on iOS
String getGeoUrl(String lat, String long, Platform platform) {
  String prefix = (platform.isIOS) ? 'maps:' : 'geo:';
  return prefix + lat + ',' + long + '?q=' + lat + ',' + long;
}

/// Launches an URL (like http, geo, etc) in any application the device provides
void launchUrl(String url) async {
  if (await canLaunch(url)) {
    await launch(url);
  } else {
    throw 'Could not launch $url';
  }
}

/// Returns true if the device is connected to any network
Future<bool> hasConnectivity() async {
  var connResult = await Connectivity().checkConnectivity();
  bool hasConn = (connResult == ConnectivityResult.none) ? false : true;
  return hasConn;
}

/// Return the title padding for the app bar title in an expanded app bar
EdgeInsets getPlatformDependentTitlePadding(bool isCollapsed) {
  if (LocalPlatform().isAndroid) {
    if (isCollapsed) {
      // align to the far left if flexible space is expanded
      return EdgeInsets.only(bottom: 16.0, left: 56.0);
    } else {
      return EdgeInsets.only(bottom: 16.0, left: 16.0);
    }
  } else if (LocalPlatform().isIOS) {
    // iOS centers the title
    return EdgeInsets.only(bottom: 16.0, left: 0.0);
  } else {
    return EdgeInsets.only(bottom: 16.0, left: 0.0);
  }
}

/// Returns true if DateTime [a] and DateTime [b] are on the same day
bool sameDay(DateTime a, DateTime b) {
  return a.year == b.year && a.month == b.month && a.day == b.day;
}
